#[non_exhaustive]pub enum FailureReason {
MissingToken,
InvalidToken,
AlreadyUsed,
Expired,
HostnameMismatch,
ActionMismatch,
ScoreTooLow,
Other(String),
}Expand description
A normalized reason explaining why a CAPTCHA was not accepted.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingToken
The token was missing or empty.
InvalidToken
The token was malformed or invalid.
AlreadyUsed
The token was already consumed.
Expired
The token expired before verification.
HostnameMismatch
The returned hostname did not match application policy.
ActionMismatch
The returned action did not match the requested action.
ScoreTooLow
The score was below application policy.
Other(String)
The provider returned a reason that does not have a normalized variant.